<?php

global $authenticate_text;
$authenticate_text = array (

'loginsuccessful'	=>	'Login successful.',
'loginfailed'		=>	'Login FAILED!',
'userandpass'		=>	'You didn\'t enter both a username and password.',
'youareloggedout'	=>	'You have been logged out.',
'waitwhiletransfer'	=>	'Please wait while you are transferred...',
'clicknowait'		=>	'Click here if you do not wish to wait.',


// Added in 0.9.7
'accountdisabled'       =>      'Your account is disabled.  Contact a full admin.',


);
?>
